@@ -1,4 +1,4 @@
-#revised October 24 to run slightly faster by taking mean outside of sum
+#corrected may 7, 2007 
 skew <- 
 function (x, na.rm = TRUE) 
 {
@@ -6,17 +6,16 @@ function (x, na.rm = TRUE)
         if (na.rm) {
             x <- x[!is.na(x)]
         			}
-         
+        sdx <- sd(x,na.rm=na.rm)
         mx <- mean(x)
         skewer <- sum((x - mx)^3)/(length(x) * sd(x)^3) 
         } else {
     
     skewer <- rep(NA,dim(x)[2])
     mx <- colMeans(x,na.rm=na.rm)
-    
+    sdx <- sd(x,na.rm=na.rm)
     for (i in 1:dim(x)[2]) {
-    skewer[i]<- sum((x[,i] - mx[i])^3,  na.rm = na.rm)/((length(x[,i]) - sum(is.na(x[,i])) * sd(x[,i], 
-            na.rm = na.rm)^3))
+    skewer[i] <- sum((x[,i] - mx[i])^3,  na.rm = na.rm)/((length(x[,i]) - sum(is.na(x[,i]))) * sdx[i]^3)
             }
     }
     return(skewer)
